# PyMCDM

This repo contains several methods which can be useful for solving MCDA problems.

### MCDA methods:
* TOPSIS
* VIKOR
* COPRAS
* PROMETHEE I and II
* COMET
* SPOTIS

### Weighting methods:
* Equal weights
* Entropy method
* Std method

### Normalization methods:
* Linear
* Max
* Sum
* Vector
* Logarithmic

### Correlation coefficients:
* Spearman
* Pearson
* Weighted Spearman
* Rank Similarity Coefficient
* Kendall Tau
* Goodman and Kruskal Gamma
